@@ -76,6 +76,7 @@ sub spawn {
             # public events
             attack                         => \&_onpub_attack,
             attack_info                    => \&_onpub_attack_info,
+            attack_move                    => \&_onpub_attack_move,
             chnum                          => \&_onpub_country_redraw,
             chown                          => \&_onpub_country_redraw,
             game_over                      => \&_onpub_game_over,
@@ -189,6 +190,26 @@ sub _onpub_attack_info {
 }
 
 
+#
+# event: attack_move
+#
+# Prevent user to re-attack till he moved the armies.
+#
+sub _onpub_attack_move {
+    my $h = $_[HEAP];
+
+    my $c = $h->{canvas};
+    $h->{toplevel}->bind('<Key-space>', undef);  # can't re-attack
+    $h->{toplevel}->bind('<Key-Return>', undef); # done attack
+    $c->CanvasBind('<1>', undef);
+    $c->CanvasBind('<3>', undef);
+    $h->{labels}{attack}->configure(@ENOFF);
+    $h->{buttons}{attack_redo}->configure(@ENOFF);
+    $h->{buttons}{attack_done}->configure(@ENOFF);
+
+}
+
+
 #
 # event: chnum($country);
 # event: chown($country);
@@ -918,7 +939,7 @@ sub _ongui_canvas_configure {
     my $gd   = $orig->resize($neww, $newh, 0);
 
     # install this new image inplace of previous background
-    my $img = $c->Photo( -data => encode_base64($gd->png) );
+    my $img = $c->Photo( -data => encode_base64($gd->jpeg) );
     $c->delete('background');
     $c->createImage(0, 0, -anchor=>'nw', -image=>$img, -tags=>['background']);
     $c->lower('background', 'all');
